## Garner python client is a library to interface with garner for easy real-time data crowdsourcing!

Use Garner to gather data for machine learning projects in realtime, allowing your to curate and
gather data smarter.

[Sign up for a free account →](https://garner.app)

[Get in contact →](https://garner.app/contact/)

![Bitbucket open issues](https://img.shields.io/bitbucket/issues-raw/kipgparker/Garner-python) ![GitHub closed issues](https://img.shields.io/github/issues-closed/kipgparker/Garner-python)
